@@ -7,8 +7,7 @@ def median_flow(hydrogram: list) -> tuple:
         bucket = int(d[1])
         hist[bucket] = hist.get(bucket, 0) + 1
 
-    # import pdb; pdb.set_trace()
-    l = len(hist) / 2
+    l = sum(hist.values()) / 2
     c = 0
     for b in sorted(hist.keys()):
         if c + hist[b] > l:
@@ -21,12 +20,12 @@ def median_flow(hydrogram: list) -> tuple:
 def gen_hydrogram(
     hydrogram: list
 ) -> Generator[float, None, float]:
+    m, mt = median_flow(hydrogram)
     t = 0
     r = tuple(float(v) for v in hydrogram.pop(0))
-    median, mtime = median_flow(hydrogram)
     while True:
-        if r[1] <= median and t >= mtime:
-            yield median
+        if r[1] <= m and t >= mt:
+            yield m
         else:
             if t >= float(hydrogram[0][0]):
                 r = tuple(float(v) for v in hydrogram.pop(0))
